use crate::{config::SSHConfig, linux::install_file, pkg::install_pkgs, print_status};
use std::io::Write;

/// Setup SSH on the system
///
/// This should be done after `setup_users()` to ensure that the users directories exist.
pub fn setup_ssh(conf: Option<SSHConfig>) {
    if let Some(conf) = conf {
        install_pkgs(&["openssh"]);

        if let Some(sshd_config) = &conf.sshd_config {
            print_status("Writing /etc/ssh/sshd_config");
            let content = std::fs::read_to_string(sshd_config).unwrap();
            install_file("/mnt/etc/ssh/sshd_config", &content, 0o644);
        }

        for key in &conf.key.unwrap_or_default() {
            for user in &key.users {
                let path = if user == "root" {
                    std::fs::create_dir_all("/root/.ssh").unwrap();
                    "/root/.ssh/authorized_keys".to_string()
                } else {
                    std::fs::create_dir_all(format!("/home/{user}/.ssh")).unwrap();
                    format!("/home/{user}/.ssh/authorized_keys")
                };

                let mut authorized_keys = std::fs::OpenOptions::new()
                    .append(true)
                    .create(true)
                    .open(path)
                    .unwrap();

                print_status(&format!("Adding key to authorized_keys for {user}"));
                writeln!(authorized_keys, "{}\n", key.key).unwrap();
            }
        }
    }
}
