use crate::{
    config::UserConfig,
    linux::{arch_chroot, install_file},
    print_status,
};

pub fn change_passwd(user: &str, pw: &str) {
    arch_chroot(&["passwd", user], Some(&format!("{}\n{}\n", pw, pw)), false);
}

/// Setup the users of the system
pub fn setup_users(conf: &[UserConfig]) {
    let mut doas_conf = String::new();

    for user in conf {
        arch_chroot(&["useradd", "-m", &user.name], None, false);

        change_passwd(&user.name, &user.password);

        if user.doas_root.unwrap_or_default() {
            print_status(&format!("Allowing root doas for {}", user.name));
            doas_conf.push_str(&format!("permit {} as root\n", user.name));
        }
    }

    install_file("/mnt/etc/doas.conf", &doas_conf, 0o644);
}
